""" pyMCR: Pythonic Multivariate Curve Resolution - Alternating Least Squares """
from . import mcr
from . import constraints
from . import metrics
from . import regressors
from . import condition

from ._version import __version__